@@ -2,19 +2,18 @@
 
 //! This module is mostly brought from https://github.com/denoland/deno/blob/96d05829002ef065b8fc84fe70de062cff0e95b3/cli/ast/mod.rs
 
+use deno_ast::swc::ast::EsVersion;
 use deno_ast::swc::common::comments::{
   Comment, CommentKind, SingleThreadedComments,
 };
 use deno_ast::swc::common::{FileName, SourceMap, Span};
 use deno_ast::swc::parser::lexer::Lexer;
 use deno_ast::swc::parser::token::Token;
-use deno_ast::swc::parser::{
-  EsConfig, JscTarget, StringInput, Syntax, TsConfig,
-};
+use deno_ast::swc::parser::{EsConfig, StringInput, Syntax, TsConfig};
 use std::convert::TryFrom;
 use std::ops::Range;
 
-static TARGET: JscTarget = JscTarget::Es2020;
+static ES_VERSION: EsVersion = EsVersion::Es2021;
 
 pub fn lex(source: &str, media_type: MediaType) -> Vec<LexedItem> {
   let source_map = SourceMap::default();
@@ -25,7 +24,7 @@ pub fn lex(source: &str, media_type: MediaType) -> Vec<LexedItem> {
   let comments = SingleThreadedComments::default();
   let lexer = Lexer::new(
     media_type.syntax(),
-    TARGET,
+    ES_VERSION,
     StringInput::from(source_file.as_ref()),
     Some(&comments),
   );
@@ -89,18 +88,8 @@ impl MediaType {
   fn syntax(&self) -> Syntax {
     fn get_es_config(jsx: bool) -> EsConfig {
       EsConfig {
-        class_private_methods: true,
-        class_private_props: true,
-        class_props: true,
-        dynamic_import: true,
         export_default_from: true,
-        export_namespace_from: true,
-        import_meta: true,
         jsx,
-        nullish_coalescing: true,
-        num_sep: true,
-        optional_chaining: true,
-        top_level_await: true,
         ..EsConfig::default()
       }
     }
@@ -108,7 +97,6 @@ impl MediaType {
       TsConfig {
         decorators: true,
         dts,
-        dynamic_import: true,
         tsx,
         ..TsConfig::default()
       }
